#ifndef EDV_ARCHIVE_DELETE_H
#define EDV_ARCHIVE_DELETE_H

#include <gtk/gtk.h>
#include "edv_types.h"


extern const gchar *EDVArchDeleteGetError(edv_core_struct *core);

extern gint EDVArchDelete(
	edv_core_struct *core,
	const gchar *arch_path,
	GList *obj_list,			/* List of edv_archive_object_struct * objects */
	const gchar *password,
	GtkWidget *toplevel,
	const gboolean show_progress, const gboolean interactive,
	gboolean *yes_to_all
);


#endif	/* EDV_ARCHIVE_DELETE_H */
